@@ -1,7 +1,7 @@
 /*
  * SIP library code.
  *
- * Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2019 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -22,7 +22,6 @@
 #include <stddef.h>
 #include <string.h>
 
-#include "sip.h"
 #include "sipint.h"
 #include "array.h"
 
@@ -201,9 +200,7 @@ static PyObject *sipVoidPtr_setwriteable(sipVoidPtrObject *v, PyObject *arg)
 {
     int rw;
 
-    rw = (int)SIPLong_AsLong(arg);
-
-    if (PyErr_Occurred())
+    if ((rw = PyObject_IsTrue(arg)) < 0)
         return NULL;
 
     v->rw = rw;
@@ -314,7 +311,11 @@ static PyNumberMethods sipVoidPtr_NumberMethods = {
     0,                      /* nb_inplace_floor_divide */
     0,                      /* nb_inplace_true_divide */
 #if PY_VERSION_HEX >= 0x02050000
-    0                       /* nb_index */
+    0,                      /* nb_index */
+#endif
+#if PY_VERSION_HEX >= 0x03050000
+    0,                      /* nb_matrix_multiply */
+    0,                      /* nb_inplace_matrix_multiply */
 #endif
 };
 
@@ -475,7 +476,7 @@ static PyObject *sipVoidPtr_subscript(PyObject *self, PyObject *key)
     {
         Py_ssize_t start, stop, step, slicelength;
 
-        if (sipConvertFromSliceObject(key, v->size, &start, &stop, &step, &slicelength) < 0)
+        if (sip_api_convert_from_slice_object(key, v->size, &start, &stop, &step, &slicelength) < 0)
             return NULL;
 
         if (step != 1)
@@ -532,7 +533,7 @@ static int sipVoidPtr_ass_subscript(PyObject *self, PyObject *key,
     {
         Py_ssize_t stop, step;
 
-        if (sipConvertFromSliceObject(key, v->size, &start, &stop, &step, &size) < 0)
+        if (sip_api_convert_from_slice_object(key, v->size, &start, &stop, &step, &size) < 0)
             return -1;
 
         if (step != 1)
@@ -801,6 +802,9 @@ PyTypeObject sipVoidPtr_Type = {
 #if PY_VERSION_HEX >= 0x03040000
     0,                      /* tp_finalize */
 #endif
+#if PY_VERSION_HEX >= 0x03080000
+    0,                      /* tp_vectorcall */
+#endif
 };
 
 
@@ -1063,10 +1067,14 @@ static int vp_convertor(PyObject *arg, struct vp_values *vp)
 
         if (PyErr_Occurred())
         {
-#if PY_VERSION_HEX >= 0x03010000
-            PyErr_SetString(PyExc_TypeError, "a single integer, CObject, None, buffer protocol implementor or another sip.voidptr object is required");
+#if defined(SIP_USE_PYCAPSULE)
+#if defined(SIP_SUPPORT_PYCOBJECT)
+            PyErr_SetString(PyExc_TypeError, "a single integer, Capsule, CObject, None, bytes-like object or another sip.voidptr object is required");
 #else
-            PyErr_SetString(PyExc_TypeError, "a single integer, Capsule, CObject, None, buffer protocol implementor or another sip.voidptr object is required");
+            PyErr_SetString(PyExc_TypeError, "a single integer, Capsule, None, bytes-like object or another sip.voidptr object is required");
+#endif
+#else
+            PyErr_SetString(PyExc_TypeError, "a single integer, CObject, None, bytes-like object or another sip.voidptr object is required");
 #endif
             return 0;
         }
